==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/types2/StructWithBinary.java <==

package org.apache.type_test.types2;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.HexBinaryAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for StructWithBinary complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithBinary">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="hex" type="{http://www.w3.org/2001/XMLSchema}hexBinary"/>
 *         &lt;element name="base64" type="{http://www.w3.org/2001/XMLSchema}base64Binary"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithBinary", propOrder = {
    "hex",
    "base64"
})
public class StructWithBinary {

    @XmlElement(namespace = "http://apache.org/type_test/types2", required = true, type = String.class)
    @XmlJavaTypeAdapter(HexBinaryAdapter.class)
    protected byte[] hex;
    @XmlElement(namespace = "http://apache.org/type_test/types2", required = true)
    protected byte[] base64;

    /**
     * Gets the value of the hex property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public byte[] getHex() {
        return hex;
    }

    /**
     * Sets the value of the hex property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHex(byte[] value) {
        this.hex = ((byte[]) value);
    }

    /**
     * Gets the value of the base64 property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getBase64() {
        return base64;
    }

    /**
     * Sets the value of the base64 property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setBase64(byte[] value) {
        this.base64 = ((byte[]) value);
    }

}

==> cxf-testutils-2.1.3.20-fuse-sources.jar: org/apache/type_test/types2/StructWithBinary.java <==

package org.apache.type_test.types2;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.HexBinaryAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for StructWithBinary complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StructWithBinary">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="hex" type="{http://www.w3.org/2001/XMLSchema}hexBinary"/>
 *         &lt;element name="base64" type="{http://www.w3.org/2001/XMLSchema}base64Binary"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StructWithBinary", propOrder = {
    "hex",
    "base64"
})
public class StructWithBinary {

    @XmlElement(required = true, type = String.class)
    @XmlJavaTypeAdapter(HexBinaryAdapter.class)
    @XmlSchemaType(name = "hexBinary")
    protected byte[] hex;
    @XmlElement(required = true)
    protected byte[] base64;

    /**
     * Gets the value of the hex property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public byte[] getHex() {
        return hex;
    }

    /**
     * Sets the value of the hex property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setHex(byte[] value) {
        this.hex = ((byte[]) value);
    }

    /**
     * Gets the value of the base64 property.
     * 
     * @return
     *     possible object is
     *     byte[]
     */
    public byte[] getBase64() {
        return base64;
    }

    /**
     * Sets the value of the base64 property.
     * 
     * @param value
     *     allowed object is
     *     byte[]
     */
    public void setBase64(byte[] value) {
        this.base64 = ((byte[]) value);
    }

}
